@@ -14,6 +14,8 @@ GType bluetooth_type_get_type (void);
 #define BLUETOOTH_TYPE_TYPE (bluetooth_type_get_type())
 GType bluetooth_column_get_type (void);
 #define BLUETOOTH_TYPE_COLUMN (bluetooth_column_get_type())
+GType bluetooth_status_get_type (void);
+#define BLUETOOTH_TYPE_STATUS (bluetooth_status_get_type())
 G_END_DECLS
 
 #endif /* __GNOME_BLUETOOTH_ENUM_TYPES_H__ */
